slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSLanczosReorthogType

determines the type of reorthogonalization used in the Lanczos method

### Synopsis

    typedef enum { EPS_LANCZOS_REORTHOG_LOCAL,
                   EPS_LANCZOS_REORTHOG_FULL,
                   EPS_LANCZOS_REORTHOG_SELECTIVE,
                   EPS_LANCZOS_REORTHOG_PERIODIC,
                   EPS_LANCZOS_REORTHOG_PARTIAL,
                   EPS_LANCZOS_REORTHOG_DELAYED } EPSLanczosReorthogType;

### See Also

EPSLanczosSetReorthog(), EPSLanczosGetReorthog()

### Level

advanced

### Location

include/slepceps.h
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages